@@ -4,6 +4,8 @@ function(cop=NULL, u, v,
          derdir=c("left", "right", "center"), ...) {
 
     derdir <- match.arg(derdir)
+    if(v - delv < 0) derdir <- "left"
+    if(v + delv > 1) derdir <- "right"
     #str(cop)
     if(derdir == "left") {
       return((cop(u,v+delv,...) - cop(u,v,...))/delv)
@@ -13,3 +15,4 @@ function(cop=NULL, u, v,
       return((cop(u,v+delv,...) - cop(u,v-delv,...))/(2*delv))
     }
 }
+
